AFQ Tractometry Pipeline
~~~~~~~~~~~~~~~~~~~~~~~~

.. image:: _static/tract_modeling2.png
          :target: modeling.html
          :align: left
          :width: 50%
.. image:: _static/down_left_arrow.png
          :align: right
          :width: 30%
.. image:: _static/tract_tractography.png
          :target: tractography.html
          :align: right
          :width: 50%
.. image:: _static/down_right_arrow.png
          :align: left
          :width: 30%
.. image:: _static/tract_recognition.png
          :target: recognition.html
          :align: left
          :width: 50%
.. image:: _static/down_left_arrow.png
          :align: right
          :width: 30%
.. image:: _static/tract_profiling.png
          :width: 50%
          :target: profiling.html
          :align: right
.. image:: _static/greencheck.png
          :align: left
          :width: 30%
